Chaussette
==========

Chaussette is a WSGI server.

.. image:: https://secure.travis-ci.org/mozilla-services/chaussette.png?branch=master
   :alt: Build Status
   :target: https://secure.travis-ci.org/mozilla-services/chaussette/

.. image:: https://coveralls.io/repos/mozilla-services/chaussette/badge.png?branch=master
   :alt: Coverage Status on master
   :target: https://coveralls.io/r/mozilla-services/chaussette?branch=master

.. image:: https://pypip.in/v/chaussette/badge.png
   :target: https://crate.io/packages/chaussette/

.. image:: https://pypip.in/d/chaussette/badge.png
   :target: https://crate.io/packages/chaussette/


Links:

- The full documentation is located at : http://chaussette.readthedocs.org
- You can reach us for any feedback, bug report, or to contribute, at
  https://github.com/mozilla-services/chaussette
